@@ -13,19 +13,32 @@
 # limitations under the License.
 import os
 import warnings
-from typing import Any, Dict
+from typing import Any, Dict, Optional, Type
 
 import torch
 import torch.nn as nn
 
 from flash.audio.speech_recognition.backbone import SPEECH_RECOGNITION_BACKBONES
 from flash.audio.speech_recognition.collate import DataCollatorCTCWithPadding
-from flash.audio.speech_recognition.data import SpeechRecognitionBackboneState
+from flash.audio.speech_recognition.input import SpeechRecognitionDeserializer
+from flash.audio.speech_recognition.output_transform import (
+    SpeechRecognitionBackboneState,
+    SpeechRecognitionOutputTransform,
+)
+from flash.core.data.io.input import ServeInput
+from flash.core.data.io.input_transform import InputTransform
 from flash.core.data.states import CollateFn
 from flash.core.model import Task
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.imports import _AUDIO_AVAILABLE
-from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.serve import Composition
+from flash.core.utilities.imports import _AUDIO_AVAILABLE, requires
+from flash.core.utilities.types import (
+    INPUT_TRANSFORM_TYPE,
+    LR_SCHEDULER_TYPE,
+    OPTIMIZER_TYPE,
+    OUTPUT_TRANSFORM_TYPE,
+    OUTPUT_TYPE,
+)
 
 if _AUDIO_AVAILABLE:
     from transformers import Wav2Vec2Processor
@@ -41,7 +54,7 @@ class SpeechRecognition(Task):
         learning_rate: Learning rate to use for training, defaults to ``1e-5``.
         optimizer: Optimizer to use for training.
         lr_scheduler: The LR scheduler to use during training.
-        serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
     """
 
     backbones: FlashRegistry = SPEECH_RECOGNITION_BACKBONES
@@ -54,7 +67,8 @@ class SpeechRecognition(Task):
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         learning_rate: float = 1e-5,
-        serializer: SERIALIZER_TYPE = None,
+        output: OUTPUT_TYPE = None,
+        output_transform: OUTPUT_TRANSFORM_TYPE = SpeechRecognitionOutputTransform(),
     ):
         os.environ["TOKENIZERS_PARALLELISM"] = "TRUE"
         # disable HF thousand warnings
@@ -68,7 +82,8 @@ class SpeechRecognition(Task):
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
             learning_rate=learning_rate,
-            serializer=serializer,
+            output=output,
+            output_transform=output_transform,
         )
 
         self.save_hyperparameters()
@@ -86,3 +101,15 @@ class SpeechRecognition(Task):
         out = self.model(batch["input_values"], labels=batch["labels"])
         out["logs"] = {"loss": out.loss}
         return out
+
+    @requires("serve")
+    def serve(
+        self,
+        host: str = "127.0.0.1",
+        port: int = 8000,
+        sanity_check: bool = True,
+        input_cls: Optional[Type[ServeInput]] = SpeechRecognitionDeserializer,
+        transform: INPUT_TRANSFORM_TYPE = InputTransform,
+        transform_kwargs: Optional[Dict] = None,
+    ) -> Composition:
+        return super().serve(host, port, sanity_check, input_cls, transform, transform_kwargs)
