@@ -16,11 +16,12 @@ from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, TYPE_
 import torch
 import torch.nn.functional as F
 import torchmetrics
-from pytorch_lightning.utilities import rank_zero_warn
+from pytorch_lightning.utilities import rank_zero_deprecation, rank_zero_warn
 
 from flash.core.adapter import AdapterTask
-from flash.core.data.data_source import DefaultDataKeys, LabelsState
-from flash.core.data.process import Serializer
+from flash.core.data.io.classification_input import ClassificationState
+from flash.core.data.io.input import DataKeys
+from flash.core.data.io.output import Output
 from flash.core.model import Task
 from flash.core.utilities.imports import _FIFTYONE_AVAILABLE, lazy_import, requires
 
@@ -68,7 +69,7 @@ class ClassificationTask(Task, ClassificationMixin):
         loss_fn: Optional[Callable] = None,
         metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
         multi_label: bool = False,
-        serializer: Optional[Union[Serializer, Mapping[str, Serializer]]] = None,
+        output: Optional[Union[Output, Mapping[str, Output]]] = None,
         **kwargs,
     ) -> None:
 
@@ -78,7 +79,7 @@ class ClassificationTask(Task, ClassificationMixin):
             *args,
             loss_fn=loss_fn,
             metrics=metrics,
-            serializer=serializer or Classes(multi_label=multi_label),
+            output=output or ClassesOutput(multi_label=multi_label),
             **kwargs,
         )
 
@@ -91,7 +92,7 @@ class ClassificationAdapterTask(AdapterTask, ClassificationMixin):
         loss_fn: Optional[Callable] = None,
         metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
         multi_label: bool = False,
-        serializer: Optional[Union[Serializer, Mapping[str, Serializer]]] = None,
+        output: Optional[Union[Output, Mapping[str, Output]]] = None,
         **kwargs,
     ) -> None:
 
@@ -101,13 +102,13 @@ class ClassificationAdapterTask(AdapterTask, ClassificationMixin):
             *args,
             loss_fn=loss_fn,
             metrics=metrics,
-            serializer=serializer or Classes(multi_label=multi_label),
+            output=output or ClassesOutput(multi_label=multi_label),
             **kwargs,
         )
 
 
-class ClassificationSerializer(Serializer):
-    """A base class for classification serializers.
+class ClassificationOutput(Output):
+    """A base class for classification outputs.
 
     Args:
         multi_label: If true, treats outputs as multi label logits.
@@ -123,39 +124,39 @@ class ClassificationSerializer(Serializer):
         return self._mutli_label
 
 
-class PredsClassificationSerializer(ClassificationSerializer):
-    """A :class:`~flash.core.classification.ClassificationSerializer` which gets the
-    :attr:`~flash.core.data.data_source.DefaultDataKeys.PREDS` from the sample.
+class PredsClassificationOutput(ClassificationOutput):
+    """A :class:`~flash.core.classification.ClassificationOutput` which gets the
+    :attr:`~flash.core.data.io.input.InputFormat.PREDS` from the sample.
     """
 
-    def serialize(self, sample: Any) -> Any:
-        if isinstance(sample, Mapping) and DefaultDataKeys.PREDS in sample:
-            sample = sample[DefaultDataKeys.PREDS]
+    def transform(self, sample: Any) -> Any:
+        if isinstance(sample, Mapping) and DataKeys.PREDS in sample:
+            sample = sample[DataKeys.PREDS]
         if not isinstance(sample, torch.Tensor):
             sample = torch.tensor(sample)
         return sample
 
 
-class Logits(PredsClassificationSerializer):
-    """A :class:`.Serializer` which simply converts the model outputs (assumed to be logits) to a list."""
+class LogitsOutput(PredsClassificationOutput):
+    """A :class:`.Output` which simply converts the model outputs (assumed to be logits) to a list."""
 
-    def serialize(self, sample: Any) -> Any:
-        return super().serialize(sample).tolist()
+    def transform(self, sample: Any) -> Any:
+        return super().transform(sample).tolist()
 
 
-class Probabilities(PredsClassificationSerializer):
-    """A :class:`.Serializer` which applies a softmax to the model outputs (assumed to be logits) and converts to a
+class ProbabilitiesOutput(PredsClassificationOutput):
+    """A :class:`.Output` which applies a softmax to the model outputs (assumed to be logits) and converts to a
     list."""
 
-    def serialize(self, sample: Any) -> Any:
-        sample = super().serialize(sample)
+    def transform(self, sample: Any) -> Any:
+        sample = super().transform(sample)
         if self.multi_label:
             return torch.sigmoid(sample).tolist()
         return torch.softmax(sample, -1).tolist()
 
 
-class Classes(PredsClassificationSerializer):
-    """A :class:`.Serializer` which applies an argmax to the model outputs (either logits or probabilities) and
+class ClassesOutput(PredsClassificationOutput):
+    """A :class:`.Output` which applies an argmax to the model outputs (either logits or probabilities) and
     converts to a list.
 
     Args:
@@ -168,8 +169,8 @@ class Classes(PredsClassificationSerializer):
 
         self.threshold = threshold
 
-    def serialize(self, sample: Any) -> Union[int, List[int]]:
-        sample = super().serialize(sample)
+    def transform(self, sample: Any) -> Union[int, List[int]]:
+        sample = super().transform(sample)
         if self.multi_label:
             one_hot = (sample.sigmoid() > self.threshold).int().tolist()
             result = []
@@ -180,13 +181,13 @@ class Classes(PredsClassificationSerializer):
         return torch.argmax(sample, -1).tolist()
 
 
-class Labels(Classes):
-    """A :class:`.Serializer` which converts the model outputs (either logits or probabilities) to the label of the
+class LabelsOutput(ClassesOutput):
+    """A :class:`.Output` which converts the model outputs (either logits or probabilities) to the label of the
     argmax classification.
 
     Args:
         labels: A list of labels, assumed to map the class index to the label for that class. If ``labels`` is not
-            provided, will attempt to get them from the :class:`.LabelsState`.
+            provided, will attempt to get them from the :class:`.ClassificationState`.
         multi_label: If true, treats outputs as multi label logits.
         threshold: The threshold to use for multi_label classification.
     """
@@ -196,34 +197,34 @@ class Labels(Classes):
         self._labels = labels
 
         if labels is not None:
-            self.set_state(LabelsState(labels))
+            self.set_state(ClassificationState(labels))
 
-    def serialize(self, sample: Any) -> Union[int, List[int], str, List[str]]:
+    def transform(self, sample: Any) -> Union[int, List[int], str, List[str]]:
         labels = None
 
         if self._labels is not None:
             labels = self._labels
         else:
-            state = self.get_state(LabelsState)
+            state = self.get_state(ClassificationState)
             if state is not None:
                 labels = state.labels
 
-        classes = super().serialize(sample)
+        classes = super().transform(sample)
 
         if labels is not None:
             if self.multi_label:
                 return [labels[cls] for cls in classes]
             return labels[classes]
-        rank_zero_warn("No LabelsState was found, this serializer will act as a Classes serializer.", UserWarning)
+        rank_zero_warn("No ClassificationState was found, this output will act as a Classes output.", UserWarning)
         return classes
 
 
-class FiftyOneLabels(ClassificationSerializer):
-    """A :class:`.Serializer` which converts the model outputs to FiftyOne classification format.
+class FiftyOneLabelsOutput(ClassificationOutput):
+    """A :class:`.Output` which converts the model outputs to FiftyOne classification format.
 
     Args:
         labels: A list of labels, assumed to map the class index to the label for that class. If ``labels`` is not
-            provided, will attempt to get them from the :class:`.LabelsState`.
+            provided, will attempt to get them from the :class:`.ClassificationState`.
         multi_label: If true, treats outputs as multi label logits.
         threshold: A threshold to use to filter candidate labels. In the single label case, predictions below this
             threshold will be replaced with None
@@ -252,13 +253,13 @@ class FiftyOneLabels(ClassificationSerializer):
         self.return_filepath = return_filepath
 
         if labels is not None:
-            self.set_state(LabelsState(labels))
+            self.set_state(ClassificationState(labels))
 
-    def serialize(
+    def transform(
         self,
         sample: Any,
     ) -> Union[Classification, Classifications, Dict[str, Any]]:
-        pred = sample[DefaultDataKeys.PREDS] if isinstance(sample, Dict) else sample
+        pred = sample[DataKeys.PREDS] if isinstance(sample, Dict) else sample
         pred = torch.tensor(pred)
 
         labels = None
@@ -266,7 +267,7 @@ class FiftyOneLabels(ClassificationSerializer):
         if self._labels is not None:
             labels = self._labels
         else:
-            state = self.get_state(LabelsState)
+            state = self.get_state(ClassificationState)
             if state is not None:
                 labels = state.labels
 
@@ -309,7 +310,7 @@ class FiftyOneLabels(ClassificationSerializer):
                         logits=logits,
                     )
         else:
-            rank_zero_warn("No LabelsState was found, int targets will be used as label strings", UserWarning)
+            rank_zero_warn("No ClassificationState was found, int targets will be used as label strings", UserWarning)
 
             if self.multi_label:
                 classifications = []
@@ -335,6 +336,23 @@ class FiftyOneLabels(ClassificationSerializer):
                     )
 
         if self.return_filepath:
-            filepath = sample[DefaultDataKeys.METADATA]["filepath"]
+            filepath = sample[DataKeys.METADATA]["filepath"]
             return {"filepath": filepath, "predictions": fo_predictions}
         return fo_predictions
+
+
+class Labels(LabelsOutput):
+    def __init__(self, labels: Optional[List[str]] = None, multi_label: bool = False, threshold: float = 0.5):
+        rank_zero_deprecation(
+            "`Labels` was deprecated in v0.6.0 and will be removed in v0.7.0." "Please use `LabelsOutput` instead."
+        )
+        super().__init__(labels=labels, multi_label=multi_label, threshold=threshold)
+
+
+class Probabilities(ProbabilitiesOutput):
+    def __init__(self, multi_label: bool = False):
+        rank_zero_deprecation(
+            "`Probabilities` was deprecated in v0.6.0 and will be removed in v0.7.0."
+            "Please use `ProbabilitiesOutput` instead."
+        )
+        super().__init__(multi_label=multi_label)
