@@ -27,13 +27,18 @@ STATE_TYPE = TypeVar("STATE_TYPE", bound=ProcessState)
 
 
 class Properties:
-    def __init__(self):
+    def __init__(
+        self,
+        running_stage: Optional[RunningStage] = None,
+        data_pipeline_state: Optional["flash.core.data.data_pipeline.DataPipelineState"] = None,
+        state: Dict[Type[ProcessState], ProcessState] = None,
+    ):
         super().__init__()
 
-        self._running_stage: Optional[RunningStage] = None
+        self._running_stage = running_stage
         self._current_fn: Optional[str] = None
-        self._data_pipeline_state: Optional["flash.core.data.data_pipeline.DataPipelineState"] = None
-        self._state: Dict[Type[ProcessState], ProcessState] = {}
+        self._data_pipeline_state = data_pipeline_state
+        self._state: Dict[Type[ProcessState], ProcessState] = {} if state is None else state
 
     def get_state(self, state_type: Type[STATE_TYPE]) -> Optional[STATE_TYPE]:
         if state_type in self._state:
@@ -48,9 +53,12 @@ class Properties:
             self._data_pipeline_state.set_state(state)
 
     def attach_data_pipeline_state(self, data_pipeline_state: "flash.core.data.data_pipeline.DataPipelineState"):
-        self._data_pipeline_state = data_pipeline_state
         for state in self._state.values():
-            self._data_pipeline_state.set_state(state)
+            data_pipeline_state.set_state(state)
+        if self._data_pipeline_state:
+            for state in self._data_pipeline_state._state.values():
+                data_pipeline_state.set_state(state)
+        self._data_pipeline_state = data_pipeline_state
 
     @property
     def current_fn(self) -> Optional[str]:
