@@ -18,12 +18,15 @@ from abc import ABCMeta
 from copy import deepcopy
 from importlib import import_module
 from typing import Any, Callable, Dict, List, Mapping, Optional, Tuple, Type, Union
+from warnings import warn
 
 import pytorch_lightning as pl
 import torch
 import torchmetrics
+from deprecate import deprecated
 from pytorch_lightning import LightningModule, Trainer
 from pytorch_lightning.callbacks import Callback
+from pytorch_lightning.callbacks.finetuning import BaseFinetuning
 from pytorch_lightning.trainer.optimizers import _get_default_scheduler_config
 from pytorch_lightning.utilities import rank_zero_warn
 from pytorch_lightning.utilities.enums import LightningEnum
@@ -34,18 +37,15 @@ from torch.optim.optimizer import Optimizer
 from torch.utils.data import DataLoader, Sampler
 
 import flash
-from flash.core.data.auto_dataset import BaseAutoDataset
 from flash.core.data.data_pipeline import DataPipeline, DataPipelineState
-from flash.core.data.data_source import DataSource
-from flash.core.data.process import (
-    Deserializer,
-    DeserializerMapping,
-    Postprocess,
-    Preprocess,
-    Serializer,
-    SerializerMapping,
-)
+from flash.core.data.io.input import InputBase, ServeInput
+from flash.core.data.io.input_transform import InputTransform
+from flash.core.data.io.output import Output
+from flash.core.data.io.output_transform import OutputTransform
+from flash.core.data.process import Deserializer, DeserializerMapping
 from flash.core.data.properties import ProcessState
+from flash.core.finetuning import _DEFAULTS_FINETUNE_STRATEGIES, _FINETUNING_STRATEGIES_REGISTRY
+from flash.core.hooks import FineTuningHooks
 from flash.core.optimizers.optimizers import _OPTIMIZERS_REGISTRY
 from flash.core.optimizers.schedulers import _SCHEDULERS_REGISTRY
 from flash.core.registry import FlashRegistry
@@ -56,14 +56,14 @@ from flash.core.utilities.providers import _HUGGINGFACE
 from flash.core.utilities.stages import RunningStage
 from flash.core.utilities.types import (
     DESERIALIZER_TYPE,
+    INPUT_TRANSFORM_TYPE,
     LOSS_FN_TYPE,
     LR_SCHEDULER_TYPE,
     METRICS_TYPE,
     MODEL_TYPE,
     OPTIMIZER_TYPE,
-    POSTPROCESS_TYPE,
-    PREPROCESS_TYPE,
-    SERIALIZER_TYPE,
+    OUTPUT_TRANSFORM_TYPE,
+    OUTPUT_TYPE,
 )
 
 
@@ -113,6 +113,10 @@ class ModuleWrapperBase:
     def attach_data_pipeline_state(self, data_pipeline_state: "DataPipelineState"):
         for state in self._state.values():
             data_pipeline_state.set_state(state)
+        if self._data_pipeline_state:
+            for state in self._data_pipeline_state._state.values():
+                data_pipeline_state.set_state(state)
+        self._data_pipeline_state = data_pipeline_state
         for child in self._children:
             child = getattr(self, child)
             if hasattr(child, "attach_data_pipeline_state"):
@@ -125,7 +129,7 @@ class DatasetProcessor:
 
     def _process_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         batch_size: int,
         num_workers: int,
         pin_memory: bool,
@@ -149,7 +153,7 @@ class DatasetProcessor:
 
     def process_train_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -173,7 +177,7 @@ class DatasetProcessor:
 
     def process_val_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -197,7 +201,7 @@ class DatasetProcessor:
 
     def process_test_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -221,7 +225,7 @@ class DatasetProcessor:
 
     def process_predict_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         batch_size: int = 1,
         num_workers: int = 0,
         pin_memory: bool = False,
@@ -259,27 +263,6 @@ class BenchmarkConvergenceCI(Callback):
                     print("Benchmark Successful!")
 
 
-def predict_context(func: Callable) -> Callable:
-    """This decorator is used as context manager to put model in eval mode before running predict and reset to
-    train after."""
-
-    @functools.wraps(func)
-    def wrapper(self, *args, **kwargs) -> Any:
-        grad_enabled = torch.is_grad_enabled()
-        is_training = self.training
-        self.eval()
-        torch.set_grad_enabled(False)
-
-        result = func(self, *args, **kwargs)
-
-        if is_training:
-            self.train()
-        torch.set_grad_enabled(grad_enabled)
-        return result
-
-    return wrapper
-
-
 class CheckDependenciesMeta(ABCMeta):
     def __new__(mcs, *args, **kwargs):
         result = ABCMeta.__new__(mcs, *args, **kwargs)
@@ -306,7 +289,7 @@ class OutputKeys(LightningEnum):
         return hash(self.value)
 
 
-class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=CheckDependenciesMeta):
+class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, FineTuningHooks, metaclass=CheckDependenciesMeta):
     """A general Task.
 
     Args:
@@ -321,14 +304,16 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             `metric(preds,target)` and return a single scalar tensor.
         deserializer: Either a single :class:`~flash.core.data.process.Deserializer` or a mapping of these to
             deserialize the input
-        preprocess: :class:`~flash.core.data.process.Preprocess` to use as the default for this task.
-        postprocess: :class:`~flash.core.data.process.Postprocess` to use as the default for this task.
-        serializer: Either a single :class:`~flash.core.data.process.Serializer` or a mapping of these to
-            serialize the output e.g. convert the model output into the desired output format when predicting.
+        input_transform: :class:`~flash.core.data.io.input_transform.InputTransform` to use as the default
+            for this task.
+        output_transform: :class:`~flash.core.data.io.output_transform.OutputTransform` to use as the default for this
+            task.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
     """
 
     optimizers: FlashRegistry = _OPTIMIZERS_REGISTRY
     lr_schedulers: FlashRegistry = _SCHEDULERS_REGISTRY
+    finetuning_strategies: FlashRegistry = _FINETUNING_STRATEGIES_REGISTRY
 
     required_extras: Optional[Union[str, List[str]]] = None
 
@@ -341,9 +326,9 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         metrics: METRICS_TYPE = None,
         deserializer: DESERIALIZER_TYPE = None,
-        preprocess: PREPROCESS_TYPE = None,
-        postprocess: POSTPROCESS_TYPE = None,
-        serializer: SERIALIZER_TYPE = None,
+        input_transform: INPUT_TRANSFORM_TYPE = None,
+        output_transform: OUTPUT_TRANSFORM_TYPE = None,
+        output: OUTPUT_TYPE = None,
     ):
         super().__init__()
         if model is not None:
@@ -360,13 +345,36 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
         self.save_hyperparameters("learning_rate", "optimizer")
 
         self._deserializer: Optional[Deserializer] = None
-        self._preprocess: Optional[Preprocess] = preprocess
-        self._postprocess: Optional[Postprocess] = postprocess
-        self._serializer: Optional[Serializer] = None
+        self._input_transform: Optional[InputTransform] = input_transform
+        self._output_transform: Optional[OutputTransform] = output_transform
+        self._output: Optional[Output] = None
 
-        # Explicitly set the serializer to call the setter
+        # Explicitly set the output to call the setter
         self.deserializer = deserializer
-        self.serializer = serializer
+        self.output = output
+        self._wrapped_predict_step = False
+
+    def _wrap_predict_step(self) -> None:
+        if not self._wrapped_predict_step:
+            process_fn = self.build_data_pipeline().output_transform_processor(RunningStage.PREDICTING)
+
+            predict_step = self.predict_step
+
+            @functools.wraps(predict_step)
+            def wrapper(*args, **kwargs):
+                predictions = predict_step(*args, **kwargs)
+                return process_fn(predictions)
+
+            self._original_predict_step = self.predict_step
+            self.predict_step = wrapper
+
+            self._wrapped_predict_step = True
+
+    def _unwrap_predict_step(self) -> None:
+        if self._wrapped_predict_step:
+            self.predict_step = self._original_predict_step
+            del self._original_predict_step
+            self._wrapped_predict_step = False
 
     def step(self, batch: Any, batch_idx: int, metrics: nn.ModuleDict) -> Any:
         """Implement the core logic for the training/validation/test step. By default this includes:
@@ -467,43 +475,8 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             prog_bar=True,
         )
 
-    @predict_context
-    def predict(
-        self,
-        x: Any,
-        data_source: Optional[str] = None,
-        deserializer: Optional[Deserializer] = None,
-        data_pipeline: Optional[DataPipeline] = None,
-    ) -> Any:
-        """Predict function for raw data or processed data.
-
-        Args:
-            x: Input to predict. Can be raw data or processed data. If str, assumed to be a folder of data.
-            data_source: A string that indicates the format of the data source to use which will override
-                the current data source format used
-            deserializer: A single :class:`~flash.core.data.process.Deserializer` to deserialize the input
-            data_pipeline: Use this to override the current data pipeline
-
-        Returns:
-            The post-processed model predictions
-        """
-        running_stage = RunningStage.PREDICTING
-
-        data_pipeline = self.build_data_pipeline(data_source or "default", deserializer, data_pipeline)
-        dataset = data_pipeline.data_source.generate_dataset(x, running_stage)
-        dataloader = self.process_predict_dataset(dataset)
-        x = list(dataloader.dataset)
-        x = data_pipeline.worker_preprocessor(running_stage, collate_fn=dataloader.collate_fn)(x)
-        # todo (tchaton): Remove this when sync with Lightning master.
-        if len(inspect.signature(self.transfer_batch_to_device).parameters) == 3:
-            x = self.transfer_batch_to_device(x, self.device, 0)
-        else:
-            x = self.transfer_batch_to_device(x, self.device)
-        x = data_pipeline.device_preprocessor(running_stage)(x)
-        x = x[0] if isinstance(x, list) else x
-        predictions = self.predict_step(x, 0)  # batch_idx is always 0 when running with `model.predict`
-        predictions = data_pipeline.postprocessor(running_stage)(predictions)
-        return predictions
+    def predict(self, *args, **kwargs):
+        raise AttributeError("`flash.Task.predict` has been removed. Use `flash.Trainer.predict` instead.")
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
         if isinstance(batch, tuple):
@@ -513,6 +486,15 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             batch = torch.stack(batch)
         return self(batch)
 
+    def modules_to_freeze(self) -> Optional[Union[nn.Module]]:
+        """By default, we try to get the ``backbone`` attribute from the task and return it or ``None`` if not
+        present.
+
+        Returns:
+            The backbone ``Module`` to freeze or ``None`` if this task does not have a ``backbone`` attribute.
+        """
+        return getattr(self, "backbone", None)
+
     def _get_optimizer_class_from_registry(self, optimizer_key: str) -> Optimizer:
         if optimizer_key.lower() not in self.available_optimizers():
             raise KeyError(
@@ -565,55 +547,87 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             return [optimizer], [self._instantiate_lr_scheduler(optimizer)]
         return optimizer
 
-    @staticmethod
-    def configure_finetune_callback() -> List[Callback]:
-        return []
+    def configure_finetune_callback(
+        self,
+        strategy: Union[str, Tuple[str, int], Tuple[str, Tuple[Tuple[int, int], int]], BaseFinetuning] = "no_freeze",
+        train_bn: bool = True,
+    ) -> List[BaseFinetuning]:
+
+        if isinstance(strategy, BaseFinetuning):
+            return [strategy]
+
+        if isinstance(strategy, str):
+            if strategy not in self.available_finetuning_strategies():
+                raise MisconfigurationException(
+                    f"Please provide a valid strategy from {_DEFAULTS_FINETUNE_STRATEGIES[:3]}."
+                )
+            finetuning_strategy_fn: Callable = self.finetuning_strategies.get(key=strategy)
+            finetuning_strategy_metadata = {"strategy_metadata": None, "train_bn": train_bn}
+        elif isinstance(strategy, Tuple):
+            if not isinstance(strategy[0], str) or strategy[0] not in self.available_finetuning_strategies():
+                raise MisconfigurationException(
+                    f"First input of `strategy` in a tuple configuration should be a string within"
+                    f" {_DEFAULTS_FINETUNE_STRATEGIES[3:]}"
+                )
+            finetuning_strategy_fn: Callable = self.finetuning_strategies.get(key=strategy[0])
+            finetuning_strategy_metadata = {"strategy_metadata": strategy[1], "train_bn": train_bn}
+        else:
+            raise MisconfigurationException(
+                "`strategy` should be a ``pytorch_lightning.callbacks.BaseFinetuning``"
+                f"callback or a str within {list(_DEFAULTS_FINETUNE_STRATEGIES[:3])}"
+                f"or a tuple configuration with {list(_DEFAULTS_FINETUNE_STRATEGIES[3:])}"
+            )
+
+        return [finetuning_strategy_fn(**finetuning_strategy_metadata)]
 
     @staticmethod
     def _resolve(
         old_deserializer: Optional[Deserializer],
-        old_preprocess: Optional[Preprocess],
-        old_postprocess: Optional[Postprocess],
-        old_serializer: Optional[Serializer],
+        old_input_transform: Optional[InputTransform],
+        old_output_transform: Optional[OutputTransform],
+        old_output: Optional[Output],
         new_deserializer: Optional[Deserializer],
-        new_preprocess: Optional[Preprocess],
-        new_postprocess: Optional[Postprocess],
-        new_serializer: Optional[Serializer],
-    ) -> Tuple[Optional[Deserializer], Optional[Preprocess], Optional[Postprocess], Optional[Serializer]]:
-        """Resolves the correct :class:`~flash.core.data.process.Preprocess`, :class:`~flash.core.data.process.Postprocess`, and
-        :class:`~flash.core.data.process.Serializer` to use, choosing ``new_*`` if it is not None or a base class
-        (:class:`~flash.core.data.process.Preprocess`, :class:`~flash.core.data.process.Postprocess`, or
-        :class:`~flash.core.data.process.Serializer`) and ``old_*`` otherwise.
+        new_input_transform: Optional[InputTransform],
+        new_output_transform: Optional[OutputTransform],
+        new_output: Optional[Output],
+    ) -> Tuple[Optional[Deserializer], Optional[InputTransform], Optional[OutputTransform], Optional[Output]]:
+        """Resolves the correct :class:`~flash.core.data.io.input_transform.InputTransform`,
+        :class:`~flash.core.data.io.output_transform.OutputTransform`, and :class:`~flash.core.data.io.output.Output`
+        to use, choosing ``new_*`` if it is not None or a base class
+        (:class:`~flash.core.data.io.input_transform.InputTransform`,
+        :class:`~flash.core.data.io.output_transform.OutputTransform`, or :class:`~flash.core.data.io.output.Output`)
+        and ``old_*`` otherwise.
 
         Args:
-            old_preprocess: :class:`~flash.core.data.process.Preprocess` to be overridden.
-            old_postprocess: :class:`~flash.core.data.process.Postprocess` to be overridden.
-            old_serializer: :class:`~flash.core.data.process.Serializer` to be overridden.
-            new_preprocess: :class:`~flash.core.data.process.Preprocess` to override with.
-            new_postprocess: :class:`~flash.core.data.process.Postprocess` to override with.
-            new_serializer: :class:`~flash.core.data.process.Serializer` to override with.
+            old_input_transform: :class:`~flash.core.data.io.input_transform.InputTransform` to be overridden.
+            old_output_transform: :class:`~flash.core.data.io.output_transform.OutputTransform` to be overridden.
+            old_output: :class:`~flash.core.data.io.output.Output` to be overridden.
+            new_input_transform: :class:`~flash.core.data.io.input_transform.InputTransform` to override with.
+            new_output_transform: :class:`~flash.core.data.io.output_transform.OutputTransform` to override with.
+            new_output: :class:`~flash.core.data.io.output.Output` to override with.
 
         Returns:
-            The resolved :class:`~flash.core.data.process.Preprocess`, :class:`~flash.core.data.process.Postprocess`,
-            and :class:`~flash.core.data.process.Serializer`.
+            The resolved :class:`~flash.core.data.io.input_transform.InputTransform`,
+            :class:`~flash.core.data.io.output_transform.OutputTransform`, and
+            :class:`~flash.core.data.io.output.Output`.
         """
         deserializer = old_deserializer
         if new_deserializer is not None and type(new_deserializer) != Deserializer:
             deserializer = new_deserializer
 
-        preprocess = old_preprocess
-        if new_preprocess is not None and type(new_preprocess) != Preprocess:
-            preprocess = new_preprocess
+        input_transform = old_input_transform
+        if new_input_transform is not None and type(new_input_transform) != InputTransform:
+            input_transform = new_input_transform
 
-        postprocess = old_postprocess
-        if new_postprocess is not None and type(new_postprocess) != Postprocess:
-            postprocess = new_postprocess
+        output_transform = old_output_transform
+        if new_output_transform is not None and type(new_output_transform) != OutputTransform:
+            output_transform = new_output_transform
 
-        serializer = old_serializer
-        if new_serializer is not None and type(new_serializer) != Serializer:
-            serializer = new_serializer
+        output = old_output
+        if new_output is not None and type(new_output) != Output:
+            output = new_output
 
-        return deserializer, preprocess, postprocess, serializer
+        return deserializer, input_transform, output_transform, output
 
     @torch.jit.unused
     @property
@@ -628,29 +642,54 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
 
     @torch.jit.unused
     @property
-    def serializer(self) -> Optional[Serializer]:
-        """The current :class:`.Serializer` associated with this model.
+    def output(self) -> Optional[Output]:
+        """The current :class:`.Output` associated with this model."""
+        return self._output
 
-        If this property was set to a mapping
-        (e.g. ``.serializer = {'output1': SerializerOne()}``) then this will be a :class:`.MappingSerializer`.
+    @torch.jit.unused
+    @output.setter
+    def output(self, output: Output):
+        self._output = output
+
+    @torch.jit.unused
+    @property
+    @deprecated(
+        None,
+        "0.6.0",
+        "0.7.0",
+        template_mgs="`Task.serializer` was deprecated in v%(deprecated_in)s in favor of `Task.output`. "
+        "It will be removed in v%(remove_in)s.",
+        stream=functools.partial(warn, category=FutureWarning),
+    )
+    def serializer(self) -> Optional[Output]:
+        """Deprecated.
+
+        Use ``Task.output`` instead.
         """
-        return self._serializer
+        return self.output
 
     @torch.jit.unused
     @serializer.setter
-    def serializer(self, serializer: Union[Serializer, Mapping[str, Serializer]]):
-        if isinstance(serializer, Mapping):
-            serializer = SerializerMapping(serializer)
-        self._serializer = serializer
+    @deprecated(
+        None,
+        "0.6.0",
+        "0.7.0",
+        template_mgs="`Task.serializer` was deprecated in v%(deprecated_in)s in favor of `Task.output`. "
+        "It will be removed in v%(remove_in)s.",
+        stream=functools.partial(warn, category=FutureWarning),
+    )
+    def serializer(self, serializer: Output):
+        self.output = serializer
 
     def build_data_pipeline(
         self,
-        data_source: Optional[str] = None,
+        input: Optional[str] = None,
         deserializer: Optional[Deserializer] = None,
         data_pipeline: Optional[DataPipeline] = None,
     ) -> Optional[DataPipeline]:
         """Build a :class:`.DataPipeline` incorporating available
-        :class:`~flash.core.data.process.Preprocess` and :class:`~flash.core.data.process.Postprocess`
+        :class:`~flash.core.data.io.input_transform.InputTransform` and
+        :class:`~flash.core.data.io.output_transform.OutputTransform`
         objects. These will be overridden in the following resolution order (lowest priority first):
 
         - Lightning ``Datamodule``, either attached to the :class:`.Trainer` or to the :class:`.Task`.
@@ -659,16 +698,17 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
         - :class:`.DataPipeline` passed to this method.
 
         Args:
-            data_source: A string that indicates the format of the data source to use which will override
+            input: A string that indicates the format of the data source to use which will override
                 the current data source format used.
             deserializer: deserializer to use
             data_pipeline: Optional highest priority source of
-                :class:`~flash.core.data.process.Preprocess` and :class:`~flash.core.data.process.Postprocess`.
+                :class:`~flash.core.data.io.input_transform.InputTransform` and
+                :class:`~flash.core.data.io.output_transform.OutputTransform`.
 
         Returns:
             The fully resolved :class:`.DataPipeline`.
         """
-        deserializer, old_data_source, preprocess, postprocess, serializer = None, None, None, None, None
+        deserializer, old_input, input_transform, output_transform, output = None, None, None, None, None
 
         # Datamodule
         datamodule = None
@@ -678,59 +718,56 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             datamodule = self.datamodule
 
         if getattr(datamodule, "data_pipeline", None) is not None:
-            old_data_source = getattr(datamodule.data_pipeline, "data_source", None)
-            preprocess = getattr(datamodule.data_pipeline, "_preprocess_pipeline", None)
-            postprocess = getattr(datamodule.data_pipeline, "_postprocess_pipeline", None)
-            serializer = getattr(datamodule.data_pipeline, "_serializer", None)
+            old_input = getattr(datamodule.data_pipeline, "input", None)
+            input_transform = getattr(datamodule.data_pipeline, "_input_transform_pipeline", None)
+            output_transform = getattr(datamodule.data_pipeline, "_output_transform", None)
+            output = getattr(datamodule.data_pipeline, "_output", None)
             deserializer = getattr(datamodule.data_pipeline, "_deserializer", None)
 
         # Defaults / task attributes
-        deserializer, preprocess, postprocess, serializer = Task._resolve(
+        deserializer, input_transform, output_transform, output = Task._resolve(
             deserializer,
-            preprocess,
-            postprocess,
-            serializer,
+            input_transform,
+            output_transform,
+            output,
             self._deserializer,
-            self._preprocess,
-            self._postprocess,
-            self._serializer,
+            self._input_transform,
+            self._output_transform,
+            self._output,
         )
 
         # Datapipeline
         if data_pipeline is not None:
-            deserializer, preprocess, postprocess, serializer = Task._resolve(
+            deserializer, input_transform, output_transform, output = Task._resolve(
                 deserializer,
-                preprocess,
-                postprocess,
-                serializer,
+                input_transform,
+                output_transform,
+                output,
                 getattr(data_pipeline, "_deserializer", None),
-                getattr(data_pipeline, "_preprocess_pipeline", None),
-                getattr(data_pipeline, "_postprocess_pipeline", None),
-                getattr(data_pipeline, "_serializer", None),
+                getattr(data_pipeline, "_input_transform_pipeline", None),
+                getattr(data_pipeline, "_output_transform", None),
+                getattr(data_pipeline, "_output", None),
             )
 
-        data_source = data_source or old_data_source
-
-        if isinstance(data_source, str):
-            if preprocess is None:
-                data_source = DataSource()  # TODO: warn the user that we are not using the specified data source
-            else:
-                data_source = preprocess.data_source_of_name(data_source)
+        input = input or old_input
 
         if deserializer is None or type(deserializer) is Deserializer:
-            deserializer = getattr(preprocess, "deserializer", deserializer)
+            deserializer = getattr(input_transform, "deserializer", deserializer)
+
+        data_pipeline = DataPipeline(
+            input=input,
+            input_transform=input_transform,
+            output_transform=output_transform,
+            deserializer=deserializer,
+            output=output,
+        )
 
-        data_pipeline = DataPipeline(data_source, preprocess, postprocess, deserializer, serializer)
         self._data_pipeline_state = self._data_pipeline_state or DataPipelineState()
+
         self.attach_data_pipeline_state(self._data_pipeline_state)
         self._data_pipeline_state = data_pipeline.initialize(self._data_pipeline_state)
         return data_pipeline
 
-    @torch.jit.unused
-    @property
-    def is_servable(self) -> bool:
-        return type(self.build_data_pipeline()._deserializer) != Deserializer
-
     @torch.jit.unused
     @property
     def data_pipeline(self) -> DataPipeline:
@@ -744,64 +781,36 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
     @torch.jit.unused
     @data_pipeline.setter
     def data_pipeline(self, data_pipeline: Optional[DataPipeline]) -> None:
-        self._deserializer, self._preprocess, self._postprocess, self.serializer = Task._resolve(
+        self._deserializer, self._input_transform, self._output_transform, self.output = Task._resolve(
             self._deserializer,
-            self._preprocess,
-            self._postprocess,
-            self._serializer,
+            self._input_transform,
+            self._output_transform,
+            self._output,
             getattr(data_pipeline, "_deserializer", None),
-            getattr(data_pipeline, "_preprocess_pipeline", None),
-            getattr(data_pipeline, "_postprocess_pipeline", None),
-            getattr(data_pipeline, "_serializer", None),
+            getattr(data_pipeline, "_input_transform_pipeline", None),
+            getattr(data_pipeline, "_output_transform", None),
+            getattr(data_pipeline, "_output", None),
         )
 
-        # self._preprocess.state_dict()
-        if getattr(self._preprocess, "_ddp_params_and_buffers_to_ignore", None):
-            self._ddp_params_and_buffers_to_ignore = self._preprocess._ddp_params_and_buffers_to_ignore
+        # self._input_transform.state_dict()
+        if getattr(self._input_transform, "_ddp_params_and_buffers_to_ignore", None):
+            self._ddp_params_and_buffers_to_ignore = self._input_transform._ddp_params_and_buffers_to_ignore
 
     @torch.jit.unused
     @property
-    def preprocess(self) -> Preprocess:
-        return getattr(self.data_pipeline, "_preprocess_pipeline", None)
+    def input_transform(self) -> InputTransform:
+        return getattr(self.data_pipeline, "_input_transform_pipeline", None)
 
     @torch.jit.unused
     @property
-    def postprocess(self) -> Postprocess:
-        return getattr(self.data_pipeline, "_postprocess_pipeline", None)
+    def output_transform(self) -> OutputTransform:
+        return getattr(self.data_pipeline, "_output_transform", None)
 
-    def on_train_dataloader(self) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self, RunningStage.TRAINING)
-            self.data_pipeline._attach_to_model(self, RunningStage.TRAINING)
-        super().on_train_dataloader()
-
-    def on_val_dataloader(self) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self, RunningStage.VALIDATING)
-            self.data_pipeline._attach_to_model(self, RunningStage.VALIDATING)
-        super().on_val_dataloader()
-
-    def on_test_dataloader(self, *_) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self, RunningStage.TESTING)
-            self.data_pipeline._attach_to_model(self, RunningStage.TESTING)
-        super().on_test_dataloader()
-
-    def on_predict_dataloader(self) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self, RunningStage.PREDICTING)
-            self.data_pipeline._attach_to_model(self, RunningStage.PREDICTING)
-        super().on_predict_dataloader()
+    def on_predict_start(self) -> None:
+        self._wrap_predict_step()
 
     def on_predict_end(self) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self)
-        super().on_predict_end()
-
-    def on_fit_end(self) -> None:
-        if self.data_pipeline is not None:
-            self.data_pipeline._detach_from_model(self)
-        super().on_fit_end()
+        self._unwrap_predict_step()
 
     def on_save_checkpoint(self, checkpoint: Dict[str, Any]) -> None:
         # This may be an issue since here we create the same problems with pickle as in
@@ -862,6 +871,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
 
     @classmethod
     def available_optimizers(cls) -> List[str]:
+        """Returns a list containing the keys of the available Optimizers."""
         registry: Optional[FlashRegistry] = getattr(cls, "optimizers", None)
         if registry is None:
             return []
@@ -869,11 +879,20 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
 
     @classmethod
     def available_lr_schedulers(cls) -> List[str]:
+        """Returns a list containing the keys of the available LR schedulers."""
         registry: Optional[FlashRegistry] = getattr(cls, "lr_schedulers", None)
         if registry is None:
             return []
         return registry.available_keys()
 
+    @classmethod
+    def available_finetuning_strategies(cls) -> List[str]:
+        """Returns a list containing the keys of the available Finetuning Strategies."""
+        registry: Optional[FlashRegistry] = getattr(cls, "finetuning_strategies", None)
+        if registry is None:
+            return []
+        return registry.available_keys()
+
     def get_num_training_steps(self) -> int:
         """Total training steps inferred from datamodule and devices."""
         if not getattr(self, "trainer", None):
@@ -946,7 +965,7 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
                     f" the second index containing the required keyword arguments to initialize the LR Scheduler and"
                     f" the third index containing a Lightning scheduler configuration dictionary of the format"
                     f" {_get_default_scheduler_config()}. NOTE: Do not set the `scheduler` key in the"
-                    f" lr_scheduler_config, it will overriden with an instance of the provided scheduler key."
+                    f" lr_scheduler_config, it will overridden with an instance of the provided scheduler key."
                 )
 
             if not isinstance(self.lr_scheduler[0], (str, Callable)):
@@ -1024,22 +1043,23 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
     def _load_from_state_dict(
         self, state_dict, prefix, local_metadata, strict, missing_keys, unexpected_keys, error_msgs
     ):
-        if "preprocess.state_dict" in state_dict:
+        if "input_transform.state_dict" in state_dict:
             try:
-                preprocess_state_dict = state_dict["preprocess.state_dict"]
-                meta = preprocess_state_dict["_meta"]
+                input_transform_state_dict = state_dict["input_transform.state_dict"]
+                meta = input_transform_state_dict["_meta"]
                 cls = getattr(import_module(meta["module"]), meta["class_name"])
-                self._preprocess = cls.load_state_dict(
-                    {k: v for k, v in preprocess_state_dict.items() if k != "_meta"},
+                self._input_transform = cls.load_state_dict(
+                    {k: v for k, v in input_transform_state_dict.items() if k != "_meta"},
                     strict=strict,
                 )
-                self._preprocess._state = meta["_state"]
-                del state_dict["preprocess.state_dict"]
-                del preprocess_state_dict["_meta"]
+                self._input_transform._state = meta["_state"]
+                del state_dict["input_transform.state_dict"]
+                del input_transform_state_dict["_meta"]
             except (ModuleNotFoundError, KeyError):
-                meta = state_dict["preprocess.state_dict"]["_meta"]
+                meta = state_dict["input_transform.state_dict"]["_meta"]
                 raise MisconfigurationException(
-                    f"The `Preprocess` {meta['module']}.{meta['class_name']} has been moved and couldn't be imported."
+                    f"The `InputTransform` {meta['module']}.{meta['class_name']}"
+                    "has been moved and couldn't be imported."
                 )
 
         super()._load_from_state_dict(
@@ -1052,36 +1072,54 @@ class Task(DatasetProcessor, ModuleWrapperBase, LightningModule, metaclass=Check
             return [BenchmarkConvergenceCI()]
 
     @requires("serve")
-    def run_serve_sanity_check(self):
-        if not self.is_servable:
-            raise NotImplementedError("This Task is not servable. Attach a Deserializer to enable serving.")
-
+    def run_serve_sanity_check(self, serve_input: ServeInput):
         from fastapi.testclient import TestClient
 
         from flash.core.serve.flash_components import build_flash_serve_model_component
 
         print("Running serve sanity check")
-        comp = build_flash_serve_model_component(self)
+        comp = build_flash_serve_model_component(self, serve_input)
         composition = Composition(predict=comp, TESTING=True, DEBUG=True)
         app = composition.serve(host="0.0.0.0", port=8000)
 
         with TestClient(app) as tc:
-            input_str = self.data_pipeline._deserializer.example_input
+            input_str = serve_input.example_input
             body = {"session": "UUID", "payload": {"inputs": {"data": input_str}}}
             resp = tc.post("http://0.0.0.0:8000/predict", json=body)
             print(f"Sanity check response: {resp.json()}")
 
     @requires("serve")
-    def serve(self, host: str = "127.0.0.1", port: int = 8000, sanity_check: bool = True) -> "Composition":
-        if not self.is_servable:
-            raise NotImplementedError("This Task is not servable. Attach a Deserializer to enable serving.")
+    def serve(
+        self,
+        host: str = "127.0.0.1",
+        port: int = 8000,
+        sanity_check: bool = True,
+        input_cls: Optional[Type[ServeInput]] = None,
+        transform: INPUT_TRANSFORM_TYPE = InputTransform,
+        transform_kwargs: Optional[Dict] = None,
+    ) -> "Composition":
+        """Serve the ``Task``. Override this method to provide a default ``input_cls``, ``transform``, and
+        ``transform_kwargs``.
 
+        Args:
+            host: The IP address to host the ``Task`` on.
+            port: The port to host on.
+            sanity_check: If ``True``, runs a sanity check before serving.
+            input_cls: The ``ServeInput`` type to use.
+            transform: The transform to use when serving.
+            transform_kwargs: Keyword arguments used to instantiate the transform.
+        """
         from flash.core.serve.flash_components import build_flash_serve_model_component
 
-        if sanity_check:
-            self.run_serve_sanity_check()
+        if input_cls is None:
+            raise NotImplementedError("The `input_cls` must be provided to enable serving.")
 
-        comp = build_flash_serve_model_component(self)
+        serve_input = input_cls(transform=transform, transform_kwargs=transform_kwargs)
+
+        if sanity_check:
+            self.run_serve_sanity_check(serve_input)
+
+        comp = build_flash_serve_model_component(self, serve_input)
         composition = Composition(predict=comp, TESTING=flash._IS_TESTING)
         composition.serve(host=host, port=port)
         return composition
