@@ -15,22 +15,19 @@ import inspect
 import warnings
 from argparse import ArgumentParser, Namespace
 from functools import wraps
-from typing import Callable, Dict, List, Optional, Tuple, Union
+from typing import Callable, List, Optional, Tuple, Union
 
 import torch
 from pytorch_lightning import LightningDataModule, LightningModule
 from pytorch_lightning import Trainer as PlTrainer
 from pytorch_lightning.callbacks import BaseFinetuning
 from pytorch_lightning.loops.fit_loop import FitLoop
-from pytorch_lightning.utilities import rank_zero_warn
 from pytorch_lightning.utilities.argparse import add_argparse_args, get_init_arguments_and_types, parse_env_variables
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.model_helpers import is_overridden
 from torch.utils.data import DataLoader
 
 import flash
-from flash.core.finetuning import _DEFAULTS_FINETUNE_STRATEGIES, instantiate_default_finetuning_callbacks
-from flash.core.utilities.imports import _PL_GREATER_EQUAL_1_5_0, _SERVE_AVAILABLE
+from flash.core.model import Task
 
 
 def from_argparse_args(cls, args: Union[Namespace, ArgumentParser], **kwargs):
@@ -75,7 +72,7 @@ def _defaults_from_env_vars(fn: Callable) -> Callable:
 
 class Trainer(PlTrainer):
     @_defaults_from_env_vars
-    def __init__(self, *args, serve_sanity_check: bool = False, **kwargs):
+    def __init__(self, *args, **kwargs):
         if flash._IS_TESTING:
             if torch.cuda.is_available():
                 kwargs["gpus"] = 1
@@ -86,23 +83,11 @@ class Trainer(PlTrainer):
                 kwargs["fast_dev_run"] = False
             else:
                 kwargs["fast_dev_run"] = True
+                kwargs["gpus"] = None
+                kwargs["accelerator"] = None
+                kwargs["precision"] = 32
         super().__init__(*args, **kwargs)
 
-        self.serve_sanity_check = serve_sanity_check
-
-    def _run_sanity_check(self, ref_model):
-        if hasattr(super(), "_run_sanity_check"):
-            super()._run_sanity_check(ref_model)
-
-        self.run_sanity_check(ref_model)
-
-    def run_sanity_check(self, ref_model):
-        if hasattr(super(), "run_sanity_check"):
-            super().run_sanity_check(ref_model)
-
-        if self.serve_sanity_check and ref_model.is_servable and _SERVE_AVAILABLE:
-            ref_model.run_serve_sanity_check()
-
     # TODO @(tchaton) remove `reset_train_val_dataloaders` from run_train function
     def _run_train(self) -> None:
         self._pre_training_routine()
@@ -157,7 +142,8 @@ class Trainer(PlTrainer):
         train_dataloader: Optional[DataLoader] = None,
         val_dataloaders: Optional[Union[DataLoader, List[DataLoader]]] = None,
         datamodule: Optional[LightningDataModule] = None,
-        strategy: Optional[Union[str, BaseFinetuning]] = None,
+        strategy: Union[str, BaseFinetuning, Tuple[str, int], Tuple[str, Tuple[int, int]]] = "no_freeze",
+        train_bn: bool = True,
     ):
         r"""
 
@@ -175,48 +161,38 @@ class Trainer(PlTrainer):
 
             datamodule: A instance of :class:`LightningDataModule`.
 
-            strategy: Should either be a string or a finetuning callback subclassing
+            strategy: Should either be a string, or a Tuple, or a finetuning callback subclassing
                 :class:`pytorch_lightning.callbacks.BaseFinetuning`.
 
-                Default strategies can be enabled with these strings:
+                Default strategies can be enabled with these inputs:
 
-                - ``"no_freeze"``,
-                - ``"freeze"``,
-                - ``"freeze_unfreeze"``,
-                - ``"unfreeze_milestones"``.
+                - ``"no_freeze"``
+                - ``"freeze"``
+                - ``("freeze_unfreeze", integer: unfreeze_epoch)``
+                - ``("unfreeze_milestones", ((integer: unfreeze_epoch_num_layers, integer: unfreeze_epoch_all_layers),
+                  integer: num_layers))``
+
+                where ``integer`` can be any integer.
+                By default, ``no_freeze`` strategy will be used.
+
+            train_bn: Whether to train Batch Norm layer
         """
-        self._resolve_callbacks(model, strategy)
+        self._resolve_callbacks(model, strategy, train_bn=train_bn)
         return super().fit(model, train_dataloader, val_dataloaders, datamodule)
 
-    def _resolve_callbacks(self, model: LightningModule, strategy: Optional[Union[str, BaseFinetuning]] = None) -> None:
+    def _resolve_callbacks(
+        self,
+        model: Task,
+        strategy: Union[str, BaseFinetuning, Tuple[str, int], Tuple[str, Tuple[int, int]]] = "no_freeze",
+        train_bn: bool = True,
+    ):
         """This function is used to select the `BaseFinetuning` to be used for finetuning."""
-        if strategy is not None and not isinstance(strategy, (str, BaseFinetuning)):
-            raise MisconfigurationException(
-                "strategy should be a ``pytorch_lightning.callbacks.BaseFinetuning``"
-                f"callback or a str within {list(_DEFAULTS_FINETUNE_STRATEGIES.keys())}"
-            )
-
-        if isinstance(strategy, BaseFinetuning):
-            callback = [strategy]
-        else:
-            # todo: change to ``configure_callbacks`` when merged to Lightning.
-            model_callback = model.configure_finetune_callback()
-            if len(model_callback) > 1:
-                raise MisconfigurationException(
-                    f"{model} configure_finetune_callback should create a list with only 1 callback"
-                )
-            if len(model_callback) == 1:
-                if strategy is not None:
-                    rank_zero_warn(
-                        "The model contains a default finetune callback. The provided {strategy} will be overriden.\n"
-                        " HINT: Provide a `BaseFinetuning` callback as strategy to make it prioritized. ",
-                        UserWarning,
-                    )
-                callback = model_callback
-            else:
-                callback = instantiate_default_finetuning_callbacks(strategy)
-
-        self.callbacks = self._merge_callbacks(self.callbacks, callback)
+        if isinstance(strategy, str) and strategy == "no_freeze":
+            warnings.warn("The model contains a default finetune callback.", UserWarning)
+        finetuning_callback = model.configure_finetune_callback(strategy=strategy, train_bn=train_bn)
+        if len(finetuning_callback) > 1:
+            raise MisconfigurationException("Create a list with only 1 finetuning callback.")
+        self.callbacks = self._merge_callbacks(self.callbacks, finetuning_callback)
 
     @staticmethod
     def _merge_callbacks(old_callbacks: List, new_callbacks: List) -> List:
@@ -244,58 +220,3 @@ class Trainer(PlTrainer):
         # the lightning trainer implementation does not support subclasses.
         # context: https://github.com/PyTorchLightning/lightning-flash/issues/342#issuecomment-848892447
         return from_argparse_args(Trainer, args, **kwargs)
-
-    def _parse_request_dataloader_args(self, args: Tuple, kwargs: Dict):
-        """Handles backwards compatibility for ``request_dataloader``.
-
-        Possible combinations:
-
-        legacy: (model, stage)
-        (stage, model)
-        (stage, model=model)
-        """
-        model, stage, is_legacy = None, None, False
-        if len(args) == 2:
-            # Check for legacy arguments: (model, stage)
-            if isinstance(args[0], LightningModule):
-                is_legacy = True
-                model, stage = args
-            else:  # (stage, model)
-                stage, model = args
-        else:
-            stage = kwargs.get("stage", args[0])
-            model = kwargs.get("model")
-        return model, stage, is_legacy
-
-    def request_dataloader(
-        self,
-        *args,
-        **kwargs,
-    ) -> Union[DataLoader, List[DataLoader]]:
-        """Handles downloading data in the GPU or TPU case.
-
-        Returns:
-            The dataloader
-        """
-        model, stage, is_legacy = self._parse_request_dataloader_args(args, kwargs)
-
-        if is_legacy:
-            self.call_hook(f"on_{stage}_dataloader")
-            dataloader = getattr(model, f"{stage}_dataloader")()
-        else:
-            hook = f"{stage.dataloader_prefix}_dataloader"
-            self.call_hook("on_" + hook, pl_module=model)
-
-            if is_overridden(hook, model):
-                dataloader = self.call_hook(hook, pl_module=model)
-            elif _PL_GREATER_EQUAL_1_5_0:
-                source = getattr(self._data_connector, f"_{stage.dataloader_prefix}_dataloader_source")
-                dataloader = source.dataloader()
-
-        if isinstance(dataloader, tuple):
-            dataloader = list(dataloader)
-        if _PL_GREATER_EQUAL_1_5_0:
-            self.training_type_plugin.barrier("get_dataloaders")
-        else:
-            self.accelerator.barrier("get_dataloaders")
-        return dataloader
