@@ -28,8 +28,7 @@ from torch.utils.data import DataLoader, IterableDataset, Sampler
 
 import flash
 from flash.core.adapter import Adapter, AdapterTask
-from flash.core.data.auto_dataset import BaseAutoDataset
-from flash.core.data.data_source import DefaultDataKeys
+from flash.core.data.io.input import DataKeys, InputBase
 from flash.core.model import Task
 from flash.core.registry import FlashRegistry
 from flash.core.utilities.compatibility import accelerator_connector
@@ -53,29 +52,10 @@ else:
 class RemapLabels(Learn2LearnRemapLabels):
     def remap(self, data, mapping):
         # remap needs to be adapted to Flash API.
-        data[DefaultDataKeys.TARGET] = mapping(data[DefaultDataKeys.TARGET])
+        data[DataKeys.TARGET] = mapping(data[DataKeys.TARGET])
         return data
 
 
-class NoModule:
-
-    """This class is used to prevent nn.Module infinite recursion."""
-
-    def __init__(self, task):
-        self.task = task
-
-    def __getattr__(self, key):
-        if key != "task":
-            return getattr(self.task, key)
-        return self.task
-
-    def __setattr__(self, key: str, value: Any) -> None:
-        if key == "task":
-            object.__setattr__(self, key, value)
-            return
-        setattr(self.task, key, value)
-
-
 class Model(torch.nn.Module):
     def __init__(self, backbone: torch.nn.Module, head: Optional[torch.nn.Module]):
         super().__init__()
@@ -97,7 +77,6 @@ class Learn2LearnAdapter(Adapter):
 
     def __init__(
         self,
-        task: AdapterTask,
         backbone: torch.nn.Module,
         head: torch.nn.Module,
         algorithm_cls: Type[LightningModule],
@@ -143,7 +122,6 @@ class Learn2LearnAdapter(Adapter):
 
         super().__init__()
 
-        self._task = NoModule(task)
         self.backbone = backbone
         self.head = head
         self.algorithm_cls = algorithm_cls
@@ -208,7 +186,7 @@ class Learn2LearnAdapter(Adapter):
     def _labels_to_indices(data):
         out = defaultdict(list)
         for idx, sample in enumerate(data):
-            label = sample[DefaultDataKeys.TARGET]
+            label = sample[DataKeys.TARGET]
             if torch.is_tensor(label):
                 label = label.item()
             out[label].append(idx)
@@ -217,7 +195,7 @@ class Learn2LearnAdapter(Adapter):
     def _convert_dataset(
         self,
         trainer: "flash.Trainer",
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         ways: int,
         shots: int,
         queries: int,
@@ -225,7 +203,7 @@ class Learn2LearnAdapter(Adapter):
         num_task: int,
         epoch_length: int,
     ):
-        if isinstance(dataset, BaseAutoDataset):
+        if isinstance(dataset, InputBase):
 
             metadata = getattr(dataset, "data", None)
             if metadata is None or (metadata is not None and not isinstance(dataset.data, list)):
@@ -309,41 +287,43 @@ class Learn2LearnAdapter(Adapter):
                 "The `shots` should be provided training_strategy_kwargs={'shots'=...}. "
                 "This is equivalent to the number of sample per label to select within a task."
             )
-        return cls(task, backbone, head, algorithm, **kwargs)
+        adapter = cls(backbone, head, algorithm, **kwargs)
+        adapter.__dict__["_task"] = task
+        return adapter
 
     def training_step(self, batch, batch_idx) -> Any:
-        input = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        input = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return self.model.training_step(input, batch_idx)
 
     def validation_step(self, batch, batch_idx):
         # Should be True only for trainer.validate
         if self.trainer.state.fn == TrainerFn.VALIDATING:
             self._algorithm_has_validated = True
-        input = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        input = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return self.model.validation_step(input, batch_idx)
 
     def validation_epoch_end(self, outpus: Any):
         self.model.validation_epoch_end(outpus)
 
     def test_step(self, batch, batch_idx):
-        input = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        input = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return self.model.test_step(input, batch_idx)
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        return self.model.predict_step(batch[DefaultDataKeys.INPUT], batch_idx, dataloader_idx=dataloader_idx)
+        return self.model.predict_step(batch[DataKeys.INPUT], batch_idx, dataloader_idx=dataloader_idx)
 
     def _sanetize_batch_size(self, batch_size: int) -> int:
         if batch_size != 1:
             warning_cache.warn(
                 "When using a meta-learning training_strategy, the batch_size should be set to 1. "
                 "HINT: You can modify the `meta_batch_size` to 100 for example by doing "
-                f"{type(self._task.task)}" + "(training_strategies_kwargs={'meta_batch_size': 100})"
+                f"{type(self._task)}" + "(training_strategies_kwargs={'meta_batch_size': 100})"
             )
         return 1
 
     def process_train_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -380,7 +360,7 @@ class Learn2LearnAdapter(Adapter):
 
     def process_val_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -417,7 +397,7 @@ class Learn2LearnAdapter(Adapter):
 
     def process_test_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         trainer: "flash.Trainer",
         batch_size: int,
         num_workers: int,
@@ -454,7 +434,7 @@ class Learn2LearnAdapter(Adapter):
 
     def process_predict_dataset(
         self,
-        dataset: BaseAutoDataset,
+        dataset: InputBase,
         batch_size: int = 1,
         num_workers: int = 0,
         pin_memory: bool = False,
@@ -486,10 +466,9 @@ class DefaultAdapter(Adapter):
 
     required_extras: str = "image"
 
-    def __init__(self, task: AdapterTask, backbone: torch.nn.Module, head: torch.nn.Module):
+    def __init__(self, backbone: torch.nn.Module, head: torch.nn.Module):
         super().__init__()
 
-        self._task = NoModule(task)
         self.backbone = backbone
         self.head = head
 
@@ -503,23 +482,25 @@ class DefaultAdapter(Adapter):
         head: torch.nn.Module,
         **kwargs,
     ) -> Adapter:
-        return cls(task, backbone, head)
+        adapter = cls(backbone, head)
+        adapter.__dict__["_task"] = task
+        return adapter
 
     def training_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return Task.training_step(self._task.task, batch, batch_idx)
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
+        return Task.training_step(self._task, batch, batch_idx)
 
     def validation_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return Task.validation_step(self._task.task, batch, batch_idx)
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
+        return Task.validation_step(self._task, batch, batch_idx)
 
     def test_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
-        return Task.test_step(self._task.task, batch, batch_idx)
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
+        return Task.test_step(self._task, batch, batch_idx)
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        batch[DefaultDataKeys.PREDS] = Task.predict_step(
-            self._task.task, (batch[DefaultDataKeys.INPUT]), batch_idx, dataloader_idx=dataloader_idx
+        batch[DataKeys.PREDS] = Task.predict_step(
+            self._task, (batch[DataKeys.INPUT]), batch_idx, dataloader_idx=dataloader_idx
         )
         return batch
 
