@@ -12,16 +12,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from types import FunctionType
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch import nn
 
-from flash.core.classification import ClassificationAdapterTask, Labels
+from flash.core.classification import ClassificationAdapterTask, LabelsOutput
+from flash.core.data.io.input import ServeInput
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.serve import Composition
+from flash.core.utilities.imports import requires
+from flash.core.utilities.types import (
+    INPUT_TRANSFORM_TYPE,
+    LOSS_FN_TYPE,
+    LR_SCHEDULER_TYPE,
+    METRICS_TYPE,
+    OPTIMIZER_TYPE,
+    OUTPUT_TYPE,
+)
 from flash.image.classification.adapters import TRAINING_STRATEGIES
 from flash.image.classification.backbones import IMAGE_CLASSIFIER_BACKBONES
+from flash.image.classification.transforms import ImageClassificationInputTransform
+from flash.image.data import ImageDeserializer
 
 
 class ImageClassifier(ClassificationAdapterTask):
@@ -60,8 +72,7 @@ class ImageClassifier(ClassificationAdapterTask):
             `metric(preds,target)` and return a single scalar tensor. Defaults to :class:`torchmetrics.Accuracy`.
         learning_rate: Learning rate to use for training, defaults to ``1e-3``.
         multi_label: Whether the targets are multi-label or not.
-        serializer: A instance of :class:`~flash.core.data.process.Serializer` or a mapping consisting of such
-            to use when serializing prediction outputs.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
         training_strategy: string indicating the training strategy. Adjust if you want to use `learn2learn`
             for doing meta-learning research
         training_strategy_kwargs: Additional kwargs for setting the training strategy
@@ -69,7 +80,6 @@ class ImageClassifier(ClassificationAdapterTask):
 
     backbones: FlashRegistry = IMAGE_CLASSIFIER_BACKBONES
     training_strategies: FlashRegistry = TRAINING_STRATEGIES
-
     required_extras: str = "image"
 
     def __init__(
@@ -85,7 +95,7 @@ class ImageClassifier(ClassificationAdapterTask):
         metrics: METRICS_TYPE = None,
         learning_rate: float = 1e-3,
         multi_label: bool = False,
-        serializer: SERIALIZER_TYPE = None,
+        output: OUTPUT_TYPE = None,
         training_strategy: Optional[str] = "default",
         training_strategy_kwargs: Optional[Dict[str, Any]] = None,
     ):
@@ -137,7 +147,7 @@ class ImageClassifier(ClassificationAdapterTask):
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
             multi_label=multi_label,
-            serializer=serializer or Labels(multi_label=multi_label),
+            output=output or LabelsOutput(multi_label=multi_label),
         )
 
     @classmethod
@@ -150,9 +160,21 @@ class ImageClassifier(ClassificationAdapterTask):
 
         return pretrained_weights
 
+    @requires("serve")
+    def serve(
+        self,
+        host: str = "127.0.0.1",
+        port: int = 8000,
+        sanity_check: bool = True,
+        input_cls: Optional[Type[ServeInput]] = ImageDeserializer,
+        transform: INPUT_TRANSFORM_TYPE = ImageClassificationInputTransform,
+        transform_kwargs: Optional[Dict] = None,
+    ) -> Composition:
+        return super().serve(host, port, sanity_check, input_cls, transform, transform_kwargs)
+
     def _ci_benchmark_fn(self, history: List[Dict[str, Any]]):
         """This function is used only for debugging usage with CI."""
         if self.hparams.multi_label:
-            assert history[-1]["val_f1"] > 0.40, history[-1]["val_f1"]
+            assert history[-1]["val_f1"] > 0.30, history[-1]["val_f1"]
         else:
             assert history[-1]["val_accuracy"] > 0.85, history[-1]["val_accuracy"]
