@@ -17,11 +17,11 @@ from pytorch_lightning.utilities import rank_zero_info
 
 from flash.core.adapter import AdapterTask
 from flash.core.data.data_pipeline import DataPipeline
-from flash.core.data.serialization import Preds
+from flash.core.data.output import PredsOutput
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, OUTPUT_TRANSFORM_TYPE, OUTPUT_TYPE
 from flash.image.instance_segmentation.backbones import INSTANCE_SEGMENTATION_HEADS
-from flash.image.instance_segmentation.data import InstanceSegmentationPostProcess, InstanceSegmentationPreprocess
+from flash.image.instance_segmentation.data import InstanceSegmentationOutputTransform
 
 
 class InstanceSegmentation(AdapterTask):
@@ -29,24 +29,16 @@ class InstanceSegmentation(AdapterTask):
     :ref:`object_detection`.
 
     Args:
-        num_classes: the number of classes for detection, including background
-        model: a string of :attr`_models`. Defaults to 'fasterrcnn'.
-        backbone: Pretained backbone CNN architecture. Constructs a model with a
-            ResNet-50-FPN backbone when no backbone is specified.
-        fpn: If True, creates a Feature Pyramind Network on top of Resnet based CNNs.
-        pretrained: if true, returns a model pre-trained on COCO train2017
-        pretrained_backbone: if true, returns a model with backbone pre-trained on Imagenet
-        trainable_backbone_layers: number of trainable resnet layers starting from final block.
-            Only applicable for `fasterrcnn`.
-        loss: the function(s) to update the model with. Has no effect for torchvision detection models.
-        metrics: The provided metrics. All metrics here will be logged to progress bar and the respective logger.
-            Changing this argument currently has no effect.
+        num_classes: The number of object classes.
+        backbone: String indicating the backbone CNN architecture to use.
+        head: String indicating the head module to use on top of the backbone.
+        pretrained: Whether the model should be loaded with it's pretrained weights.
         optimizer: Optimizer to use for training.
         lr_scheduler: The LR scheduler to use during training.
-        pretrained: Whether the model from torchvision should be loaded with it's pretrained weights.
-            Has no effect for custom models.
-        learning_rate: The learning rate to use for training
-
+        learning_rate: The learning rate to use for training.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
+        predict_kwargs: dictionary containing parameters that will be used during the prediction phase.
+        **kwargs: additional kwargs used for initializing the task
     """
 
     heads: FlashRegistry = INSTANCE_SEGMENTATION_HEADS
@@ -62,11 +54,14 @@ class InstanceSegmentation(AdapterTask):
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         learning_rate: float = 5e-4,
-        serializer: SERIALIZER_TYPE = None,
+        output_transform: OUTPUT_TRANSFORM_TYPE = InstanceSegmentationOutputTransform(),
+        output: OUTPUT_TYPE = PredsOutput(),
+        predict_kwargs: Dict = None,
         **kwargs: Any,
     ):
         self.save_hyperparameters()
 
+        predict_kwargs = predict_kwargs if predict_kwargs else {}
         metadata = self.heads.get(head, with_metadata=True)
         adapter = metadata["metadata"]["adapter"].from_task(
             self,
@@ -74,6 +69,7 @@ class InstanceSegmentation(AdapterTask):
             backbone=backbone,
             head=head,
             pretrained=pretrained,
+            predict_kwargs=predict_kwargs,
             **kwargs,
         )
 
@@ -82,7 +78,8 @@ class InstanceSegmentation(AdapterTask):
             learning_rate=learning_rate,
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
-            serializer=serializer or Preds(),
+            output_transform=output_transform,
+            output=output,
         )
 
     def _ci_benchmark_fn(self, history: List[Dict[str, Any]]) -> None:
@@ -99,5 +96,15 @@ class InstanceSegmentation(AdapterTask):
                 "If you'd like to change this, extend the InstanceSegmentation Task and override `on_load_checkpoint`."
             )
             self.data_pipeline = DataPipeline(
-                preprocess=InstanceSegmentationPreprocess(), postprocess=InstanceSegmentationPostProcess()
+                input_transform=None,
+                output_transform=InstanceSegmentationOutputTransform(),
             )
+
+    @property
+    def predict_kwargs(self) -> Dict[str, Any]:
+        """The kwargs used for the prediction step."""
+        return self.adapter.predict_kwargs
+
+    @predict_kwargs.setter
+    def predict_kwargs(self, predict_kwargs: Dict[str, Any]):
+        self.adapter.predict_kwargs = predict_kwargs
