@@ -14,35 +14,28 @@
 from typing import Any, Dict, List, Optional
 
 from flash.core.adapter import AdapterTask
-from flash.core.data.serialization import Preds
+from flash.core.data.output import PredsOutput
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, OUTPUT_TYPE
 from flash.image.keypoint_detection.backbones import KEYPOINT_DETECTION_HEADS
 
 
 class KeypointDetector(AdapterTask):
-    """The ``ObjectDetector`` is a :class:`~flash.Task` for detecting objects in images. For more details, see
-    :ref:`object_detection`.
+    """The ``KeypointDetector`` is a :class:`~flash.Task` for detecting keypoints in images. For more details, see
+    :ref:`keypoint_detection`.
 
     Args:
-        num_classes: the number of classes for detection, including background
-        model: a string of :attr`_models`. Defaults to 'fasterrcnn'.
-        backbone: Pretained backbone CNN architecture. Constructs a model with a
-            ResNet-50-FPN backbone when no backbone is specified.
-        fpn: If True, creates a Feature Pyramind Network on top of Resnet based CNNs.
-        pretrained: if true, returns a model pre-trained on COCO train2017
-        pretrained_backbone: if true, returns a model with backbone pre-trained on Imagenet
-        trainable_backbone_layers: number of trainable resnet layers starting from final block.
-            Only applicable for `fasterrcnn`.
-        loss: the function(s) to update the model with. Has no effect for torchvision detection models.
-        metrics: The provided metrics. All metrics here will be logged to progress bar and the respective logger.
-            Changing this argument currently has no effect.
+        num_keypoints: Number of keypoints to detect.
+        num_classes: The number of keypoint classes.
+        backbone: String indicating the backbone CNN architecture to use.
+        head: String indicating the head module to use on top of the backbone.
+        pretrained: Whether the model should be loaded with it's pretrained weights.
         optimizer: Optimizer to use for training.
         lr_scheduler: The LR scheduler to use during training.
-        pretrained: Whether the model from torchvision should be loaded with it's pretrained weights.
-            Has no effect for custom models.
-        learning_rate: The learning rate to use for training
-
+        learning_rate: The learning rate to use for training.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
+        predict_kwargs: dictionary containing parameters that will be used during the prediction phase.
+        **kwargs: additional kwargs used for initializing the task
     """
 
     heads: FlashRegistry = KEYPOINT_DETECTION_HEADS
@@ -59,11 +52,13 @@ class KeypointDetector(AdapterTask):
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         learning_rate: float = 5e-4,
-        serializer: SERIALIZER_TYPE = None,
+        output: OUTPUT_TYPE = None,
+        predict_kwargs: Dict = None,
         **kwargs: Any,
     ):
         self.save_hyperparameters()
 
+        predict_kwargs = predict_kwargs if predict_kwargs else {}
         metadata = self.heads.get(head, with_metadata=True)
         adapter = metadata["metadata"]["adapter"].from_task(
             self,
@@ -72,6 +67,7 @@ class KeypointDetector(AdapterTask):
             backbone=backbone,
             head=head,
             pretrained=pretrained,
+            predict_kwargs=predict_kwargs,
             **kwargs,
         )
 
@@ -80,9 +76,18 @@ class KeypointDetector(AdapterTask):
             learning_rate=learning_rate,
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
-            serializer=serializer or Preds(),
+            output=output or PredsOutput(),
         )
 
     def _ci_benchmark_fn(self, history: List[Dict[str, Any]]) -> None:
         """This function is used only for debugging usage with CI."""
         # todo
+
+    @property
+    def predict_kwargs(self) -> Dict[str, Any]:
+        """The kwargs used for the prediction step."""
+        return self.adapter.predict_kwargs
+
+    @predict_kwargs.setter
+    def predict_kwargs(self, predict_kwargs: Dict[str, Any]):
+        self.adapter.predict_kwargs = predict_kwargs
