@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Type, Union
 
 import torch
 from torch import nn
@@ -19,32 +19,36 @@ from torch.nn import functional as F
 from torchmetrics import IoU
 
 from flash.core.classification import ClassificationTask
-from flash.core.data.data_source import DefaultDataKeys
-from flash.core.data.process import Postprocess
+from flash.core.data.io.input import DataKeys, ServeInput
+from flash.core.data.io.output_transform import OutputTransform
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.imports import _KORNIA_AVAILABLE
+from flash.core.serve import Composition
+from flash.core.utilities.imports import _KORNIA_AVAILABLE, requires
 from flash.core.utilities.isinstance import _isinstance
 from flash.core.utilities.types import (
+    INPUT_TRANSFORM_TYPE,
     LOSS_FN_TYPE,
     LR_SCHEDULER_TYPE,
     METRICS_TYPE,
     OPTIMIZER_TYPE,
-    POSTPROCESS_TYPE,
-    SERIALIZER_TYPE,
+    OUTPUT_TRANSFORM_TYPE,
+    OUTPUT_TYPE,
 )
 from flash.image.segmentation.backbones import SEMANTIC_SEGMENTATION_BACKBONES
 from flash.image.segmentation.heads import SEMANTIC_SEGMENTATION_HEADS
-from flash.image.segmentation.serialization import SegmentationLabels
+from flash.image.segmentation.input import SemanticSegmentationDeserializer
+from flash.image.segmentation.output import SegmentationLabelsOutput
+from flash.image.segmentation.transforms import SemanticSegmentationInputTransform
 
 if _KORNIA_AVAILABLE:
     import kornia as K
 
 
-class SemanticSegmentationPostprocess(Postprocess):
+class SemanticSegmentationOutputTransform(OutputTransform):
     def per_sample_transform(self, sample: Any) -> Any:
-        resize = K.geometry.Resize(sample[DefaultDataKeys.METADATA]["size"][-2:], interpolation="bilinear")
-        sample[DefaultDataKeys.PREDS] = resize(sample[DefaultDataKeys.PREDS])
-        sample[DefaultDataKeys.INPUT] = resize(sample[DefaultDataKeys.INPUT])
+        resize = K.geometry.Resize(sample[DataKeys.METADATA]["size"], interpolation="bilinear")
+        sample[DataKeys.PREDS] = resize(sample[DataKeys.PREDS])
+        sample[DataKeys.INPUT] = resize(sample[DataKeys.INPUT])
         return super().per_sample_transform(sample)
 
 
@@ -68,11 +72,11 @@ class SemanticSegmentation(ClassificationTask):
             `metric(preds,target)` and return a single scalar tensor. Defaults to :class:`torchmetrics.IOU`.
         learning_rate: Learning rate to use for training.
         multi_label: Whether the targets are multi-label or not.
-        serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
-        postprocess: :class:`~flash.core.data.process.Postprocess` use for post processing samples.
+        output: The :class:`~flash.core.data.io.output.Output` to use when formatting prediction outputs.
+        output_transform: :class:`~flash.core.data.io.output_transform.OutputTransform` use for post processing samples.
     """
 
-    postprocess_cls = SemanticSegmentationPostprocess
+    output_transform_cls = SemanticSegmentationOutputTransform
 
     backbones: FlashRegistry = SEMANTIC_SEGMENTATION_BACKBONES
 
@@ -94,8 +98,8 @@ class SemanticSegmentation(ClassificationTask):
         metrics: METRICS_TYPE = None,
         learning_rate: float = 1e-3,
         multi_label: bool = False,
-        serializer: SERIALIZER_TYPE = None,
-        postprocess: POSTPROCESS_TYPE = None,
+        output: OUTPUT_TYPE = None,
+        output_transform: OUTPUT_TRANSFORM_TYPE = None,
     ) -> None:
         if metrics is None:
             metrics = IoU(num_classes=num_classes)
@@ -114,8 +118,8 @@ class SemanticSegmentation(ClassificationTask):
             lr_scheduler=lr_scheduler,
             metrics=metrics,
             learning_rate=learning_rate,
-            serializer=serializer or SegmentationLabels(),
-            postprocess=postprocess or self.postprocess_cls(),
+            output=output or SegmentationLabelsOutput(),
+            output_transform=output_transform or self.output_transform_cls(),
         )
 
         self.save_hyperparameters()
@@ -137,20 +141,20 @@ class SemanticSegmentation(ClassificationTask):
         self.backbone = self.head.encoder
 
     def training_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().training_step(batch, batch_idx)
 
     def validation_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().validation_step(batch, batch_idx)
 
     def test_step(self, batch: Any, batch_idx: int) -> Any:
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().test_step(batch, batch_idx)
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        batch_input = batch[DefaultDataKeys.INPUT]
-        batch[DefaultDataKeys.PREDS] = super().predict_step(batch_input, batch_idx, dataloader_idx=dataloader_idx)
+        batch_input = batch[DataKeys.INPUT]
+        batch[DataKeys.PREDS] = super().predict_step(batch_input, batch_idx, dataloader_idx=dataloader_idx)
         return batch
 
     def forward(self, x) -> torch.Tensor:
@@ -174,6 +178,18 @@ class SemanticSegmentation(ClassificationTask):
 
         return pretrained_weights
 
+    @requires("serve")
+    def serve(
+        self,
+        host: str = "127.0.0.1",
+        port: int = 8000,
+        sanity_check: bool = True,
+        input_cls: Optional[Type[ServeInput]] = SemanticSegmentationDeserializer,
+        transform: INPUT_TRANSFORM_TYPE = SemanticSegmentationInputTransform,
+        transform_kwargs: Optional[Dict] = None,
+    ) -> Composition:
+        return super().serve(host, port, sanity_check, input_cls, transform, transform_kwargs)
+
     @staticmethod
     def _ci_benchmark_fn(history: List[Dict[str, Any]]):
         """This function is used only for debugging usage with CI."""
