@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 from flash.core.data.utils import download_data
 from flash.core.utilities.flash_cli import FlashCLI
 from flash.pointcloud import PointCloudObjectDetector, PointCloudObjectDetectorData
@@ -21,8 +20,7 @@ __all__ = ["pointcloud_detection"]
 
 def from_kitti(
     batch_size: int = 4,
-    num_workers: int = 0,
-    **preprocess_kwargs,
+    **data_module_kwargs,
 ) -> PointCloudObjectDetectorData:
     """Downloads and loads the KITTI data set."""
     download_data("https://pl-flash-data.s3.amazonaws.com/KITTI_tiny.zip", "data/")
@@ -30,8 +28,7 @@ def from_kitti(
         train_folder="data/KITTI_Tiny/Kitti/train",
         val_folder="data/KITTI_Tiny/Kitti/val",
         batch_size=batch_size,
-        num_workers=num_workers,
-        **preprocess_kwargs,
+        **data_module_kwargs,
     )
 
 
