@@ -1,3 +1,3 @@
-from flash.text.seq2seq.core import Seq2SeqData, Seq2SeqFreezeEmbeddings, Seq2SeqTask  # noqa: F401
+from flash.text.seq2seq.core import Seq2SeqData, Seq2SeqTask  # noqa: F401
 from flash.text.seq2seq.summarization import SummarizationData, SummarizationTask  # noqa: F401
 from flash.text.seq2seq.translation import TranslationData, TranslationTask  # noqa: F401
