@@ -14,9 +14,9 @@
 from typing import Any, Dict, List, Optional
 
 import torch
+from torchmetrics import ROUGEScore
 
 from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE
-from flash.text.seq2seq.core.metrics import RougeMetric
 from flash.text.seq2seq.core.model import Seq2SeqTask
 
 
@@ -49,6 +49,7 @@ class SummarizationTask(Seq2SeqTask):
     def __init__(
         self,
         backbone: str = "sshleifer/distilbart-xsum-1-1",
+        tokenizer_kwargs: Optional[Dict[str, Any]] = None,
         loss_fn: LOSS_FN_TYPE = None,
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
@@ -63,6 +64,7 @@ class SummarizationTask(Seq2SeqTask):
         self.save_hyperparameters()
         super().__init__(
             backbone=backbone,
+            tokenizer_kwargs=tokenizer_kwargs,
             loss_fn=loss_fn,
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
@@ -72,8 +74,8 @@ class SummarizationTask(Seq2SeqTask):
             num_beams=num_beams,
             enable_ort=enable_ort,
         )
-        self.rouge = RougeMetric(
-            rouge_newline_sep=rouge_newline_sep,
+        self.rouge = ROUGEScore(
+            newline_sep=rouge_newline_sep,
             use_stemmer=use_stemmer,
         )
 
@@ -83,10 +85,10 @@ class SummarizationTask(Seq2SeqTask):
 
     def compute_metrics(self, generated_tokens: torch.Tensor, batch: Dict, prefix: str) -> None:
         tgt_lns = self.tokenize_labels(batch["labels"])
-        result = self.rouge(self._postprocess.uncollate(generated_tokens), tgt_lns)
+        result = self.rouge(self._output_transform.uncollate(generated_tokens), tgt_lns)
         self.log_dict(result, on_step=False, on_epoch=True, prog_bar=True)
 
     @staticmethod
     def _ci_benchmark_fn(history: List[Dict[str, Any]]):
         """This function is used only for debugging usage with CI."""
-        assert history[-1]["rouge1_recall"] > 0.2
+        assert history[-1]["rouge1_recall"] > 0.18, history[-1]["rouge1_recall"]
